@@ -9,10 +9,10 @@ use Exporter qw/ import /;
 
 use WebService::Slack::WebApi;
 
-our @EXPORT_OK = qw/ mocked_slack any_mocked_slack /;
+our @EXPORT_OK = qw/ mocked_slack any_mocked_slack mocked_slack_without_token /;
 
 sub mocked_slack {
-    my ($content, $is_success) = @_;
+    my ($content, $is_success, $no_token) = @_;
 
     # mock ua for HTTP::AnyUA
     # don't use with real HTTP::Tiny
@@ -22,10 +22,14 @@ sub mocked_slack {
     }, 'HTTP::Tiny';
     sub HTTP::Tiny::request { shift }
 
+    if(defined $no_token && $no_token) {
+        return WebService::Slack::WebApi->new(ua => $ua);
+    }
     return WebService::Slack::WebApi->new(token => 'a', ua => $ua);
 }
 
 sub any_mocked_slack { mocked_slack +{hoge => 'fuga'}, 1 }
+sub mocked_slack_without_token { mocked_slack +{hoge => 'fuga'}, 1, 1 }
 
 1;
 
